import ProtectedUi from 'src/components/ProtectedUi'
import { Button } from '@mui/material'
import React, { useEffect, useState } from 'react'
import Datatable from 'src/components/Datatable'
import { useRecoilState } from 'recoil'
import { SuccessMessageAtom } from 'src/atoms/SuccessMessageAtom'
import MessageComponent from 'src/components/MessageComponent'
import { InformationCircleIcon } from '@heroicons/react/solid'
import useLanguage from 'src/hooks/useLanguage'

const LanguagesIndex = () => {
  const [form, setForm] = useState(false)
  const [languageId, setLanguageId] = useState(0)
  const [revalidate, setRevalidate] = useState(false)
  const [message, setMessage] = useRecoilState(SuccessMessageAtom)
  const { translate } = useLanguage()

  const openForm = id => {
    setForm(true)
    setLanguageId(id)
  }

  useEffect(() => {
    if (languageId) {
      openForm(languageId)
    }
  }, [languageId])

  return (
    <ProtectedUi role={'languages-access'} view={false}>
      <div>
        <div className={'flex items-center justify-between'}>
          <h1 className={'text-xl'}>{translate('List of languages')}</h1>
          <Button variant={'outlined'} size={'small'} onClick={() => openForm(0)}>
            {translate('Add new language to dictionary')}
          </Button>
        </div>
        <Datatable
          url={'/language'}
          editRole={'languages-edit-language'}
          deleteRole={'languages-delete-language'}
          actions={true}
          border={false}
          onRevalidate={revalidate}
          afterValidationCompleted={e => setRevalidate(e)}
          returnId={e => setLanguageId(e)}
          editMode={'modal'}
          otherActions={[
            {
              icon: <InformationCircleIcon className={'h-4 text-blue-500'} />,
              route: '/dashboard/setting?active=languages_dictionary',
              role: 'language-translation-access'
            }
          ]}
          columns={[
            {
              name: translate('ID'),
              key: 'id',
              sort: {
                enable: true,
                key: 'id'
              }
            },
            {
              name: translate('Name'),
              key: 'name',
              sort: {
                enable: true,
                key: 'name'
              }
            },
            {
              name: translate('Abbreviation'),
              key: 'abbr',
              sort: {
                enable: true,
                key: 'abbr'
              }
            },
            {
              name: translate('Direction'),
              key: 'direction',
              sort: {
                enable: true,
                key: 'direction'
              }
            },
            {
              name: translate('Status'),
              key: 'status',
              sort: {
                enable: true,
                key: 'status'
              }
            }
          ]}
        />
      </div>
      {/* {form && (
        <LanguageForm
          languageId={languageId}
          onClose={e => {
            setForm(e)
            setLanguageId(0)
          }}
          onRevalidate={e => setRevalidate(e)}
        />
      )} */}
      {message && <MessageComponent message={message} setMessage={e => setMessage(e)} type={'success'} />}
    </ProtectedUi>
  )
}

export default LanguagesIndex
