import React, { createContext, useEffect, useState } from 'react'
import { useRecoilState } from 'recoil'
import { messageAtom } from 'src/lib/atoms/messageAtom'
import MessageComponent from 'src/components/MessageComponent'
import { useRouter } from 'next/router'
import { CircularProgress } from '@material-ui/core'

// ** ThemeConfig Import
import themeConfig from 'src/configs/themeConfig'

const initialSettings = {
  themeColor: 'primary',
  mode: themeConfig.mode,
  contentWidth: themeConfig.contentWidth
}

const AppContext = createContext({
  saveSettings: () => null,
  settings: initialSettings
})

export default AppContext

export const AppContextProvider = ({ children }) => {
  const [settings, setSettings] = useState({ ...initialSettings })

  const saveSettings = updatedSettings => {
    setSettings(updatedSettings)
  }
  const [messageType, setMessageType] = useState('success')
  const [isLogin, setIsLogin] = useState(true)
  const [loading, setLoading] = useState(true)
  const [accessToken, setAccessToken] = useState('')
  const [user, setUser] = useState('')
  const [message, setMessage] = useRecoilState(messageAtom)
  const router = useRouter()

  const [permissions, setPermissions] = useState(
    typeof window != 'undefined' && localStorage.getItem('permissions')
      ? JSON.parse(localStorage.getItem('permissions'))
      : null
  )

  const [language, setLanguage] = useState(
    typeof window != 'undefined' && localStorage.getItem('language') ? localStorage.getItem('language') : 'eng'
  )

  const [direction, setDirection] = useState(
    typeof window != 'undefined' && localStorage.getItem('direction')
      ? localStorage.getItem('direction') === 'eng'
        ? 'ltr'
        : 'rtl'
      : 'ltr'
  )

  useEffect(() => {
    if (!localStorage.getItem('language')) {
      localStorage.setItem('language', language)
    }
    if (!localStorage.getItem('direction')) {
      localStorage.setItem('direction', direction)
    }
  }, [])

  const login = accessToken => {
    setAccessToken(accessToken)
    setIsLogin(true)
    setMessageType('success')
    setMessage('Logged in successfully')
    router.push('/')
    localStorage.setItem('access_token', accessToken)
  }

  const logout = async () => {
    setAccessToken('')
    localStorage.removeItem('access_token')
    await router.push('/login')
    setIsLogin(false)
  }

  useEffect(() => {
    if (typeof localStorage !== 'undefined') {
      let access_token_value = localStorage.getItem('access_token')
      setAccessToken(access_token_value)
      if (access_token_value) {
        setIsLogin(true)
      } else {
        setIsLogin(false)
      }
    }
  }, [])

  useEffect(() => {
    setLoading(false)
  }, [])

  const context = {
    isLogin,
    setIsLogin,
    setMessageType,
    logout,
    login,
    user,
    setUser,
    accessToken,
    settings,
    saveSettings,
    language,
    setLanguage,
    direction,
    setDirection,
    permissions,
    setPermissions
  }
  
return (
    <AppContext.Provider value={context}>
      {loading ? (
        <div className='flex items-center content-center h-screen'>
          <div className='flex-1 text-center'>
            <CircularProgress size={60} />
          </div>
        </div>
      ) : (
        children
      )}
      <MessageComponent message={message} type={messageType} setMessage={e => setMessage(e)} />
    </AppContext.Provider>
  )
}

export const SettingsConsumer = AppContext.Consumer
